@@ -18,10 +18,10 @@ use League\CommonMark\Environment\Environment;
 use League\CommonMark\Extension\CommonMark\CommonMarkCoreExtension;
 use League\CommonMark\Extension\HeadingPermalink\HeadingPermalinkExtension;
 use League\CommonMark\Extension\TableOfContents\TableOfContentsExtension;
-use League\CommonMark\Tests\Functional\AbstractLocalDataTest;
+use League\CommonMark\Tests\Functional\AbstractLocalDataTestCase;
 use League\CommonMark\Xml\MarkdownToXmlConverter;
 
-final class TableOfContentsXmlTest extends AbstractLocalDataTest
+final class TableOfContentsXmlTest extends AbstractLocalDataTestCase
 {
     /**
      * @param array<string, mixed> $config
@@ -39,8 +39,8 @@ final class TableOfContentsXmlTest extends AbstractLocalDataTest
     /**
      * {@inheritDoc}
      */
-    public function dataProvider(): iterable
+    public static function dataProvider(): iterable
     {
-        yield from $this->loadTests(__DIR__ . '/xml', '*', '.md', '.xml');
+        yield from self::loadTests(__DIR__ . '/xml', '*', '.md', '.xml');
     }
 }
